@@ -28,12 +28,14 @@
 #include <KFileMetaData/UserMetaData>
 
 #include <QtWidgets/QLabel>
+#include <QtCore/QCollator>
 #include <QtCore/QTime>
 #include <QtCore/QUrl>
 #include <QtCore/QLocale>
 
 #include <KJob>
 #include <KFormat>
+#include <KLocalizedString>
 
 namespace {
     static QString plainText(const QString& richText)
@@ -107,6 +109,9 @@ QWidget* WidgetFactory::createWidget(const QString& prop, const QVariant& value,
     }
     else if (prop == QLatin1String("tags")) {
         QStringList tags = value.toStringList();
+        QCollator coll;
+        coll.setNumericMode(true);
+        std::sort(tags.begin(), tags.end(), [&](const QString& s1, const QString& s2){ return coll.compare(s1, s2) < 0; });
         widget = createTagWidget( tags, parent );
     }
     else {
@@ -114,10 +119,17 @@ QWidget* WidgetFactory::createWidget(const QString& prop, const QVariant& value,
         // vHanda: FIXME: Add links! Take m_noLinks into consideration
         QString valueString;
 
-        if (prop == "duration"){
+        if (prop == QStringLiteral("duration")) {
             valueString = form.formatDuration(value.toInt() * 1000);
-        }
-        else {
+        } else if (prop == QStringLiteral("bitRate")) {
+            valueString = i18nc("@label bitrate (per second)", "%1/s", form.formatByteSize(value.toInt(), 1, KFormat::MetricBinaryDialect));
+        } else if (prop == QLatin1String("originUrl")) {
+            if (m_noLinks) {
+                valueString = value.toString();
+            } else {
+                valueString = QStringLiteral("<a href=\"%1\">%1</a>").arg(value.toString());
+            }
+        } else {
             // Check if Date/DateTime
 
             QDateTime dt = QDateTime::fromString(value.toString(), Qt::ISODate);
